@@ -1,4 +1,5 @@
 // SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
+// SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #pragma once
@@ -12,11 +13,11 @@ namespace KIdentityManagementCore
 {
 class IdentityManager;
 class Identity;
+class IdentityActivitiesAbstract;
 }
 namespace KIdentityManagementWidgets
 {
 class IdentityComboPrivate;
-
 /// \brief A combo box that always shows the up-to-date identity list.
 /// \author Marc Mutz \<mutz@kde.org\>
 class KIDENTITYMANAGEMENTWIDGETS_EXPORT IdentityCombo : public QComboBox
@@ -53,6 +54,11 @@ public:
     /// @since 4.5
     [[nodiscard]] KIdentityManagementCore::IdentityManager *identityManager() const;
 
+    /// @since 6.1
+    [[nodiscard]] KIdentityManagementCore::IdentityActivitiesAbstract *identityActivitiesAbstract() const;
+    /// @since 6.1
+    void setIdentityActivitiesAbstract(KIdentityManagementCore::IdentityActivitiesAbstract *newIdentityActivitiesAbstract);
+
 Q_SIGNALS:
 
     /// \em Really emitted whenever the current identity changes. Either
